# itsFM :  Identify, Track and Segment Frequency and its Modulation

See https://itsfm.readthedocs.io/en/latest/ for more!



Change Log
~~~~~~~~~~
* 2020-11-18: version 0.1.0 (released)
	* ADDED: diagnostics for peak-percentage viewing
	* CHANGED: tutorials 
